package cn.sh.stc.sict.theme.hpgp.model;

import cn.sh.stc.sict.cloud.common.core.util.NumberUtil;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 黄浦全科导诊——忙闲预测(HpgpBusyIdle_ prediction)表实体类
 *
 * @author zhangly
 * @since 2022-01-14 09:56:39
 */
@Data
@EqualsAndHashCode(callSuper = true)
public class HpgpBusyIdlePrediction extends Model<HpgpBusyIdlePrediction> {
    private Long id;
    //医院代码
    @ApiModelProperty( value = "医院代码")
    private String hospitalCode;
    //医院名称
    @ApiModelProperty(value = "医院名称")
    private String hospitalName;
    private String oneDeptCode;
    //科室代码
    @ApiModelProperty(value = "科室代码")
    private String deptCode;
    //科室名称
    @ApiModelProperty(value = "科室名称")
    private String deptName;
    //预测日期
    @ApiModelProperty(value = "预测日期")
    private Date predictionDate;
    // 总号源数量
    private Integer reserveOrderNum;
    // 可预约号源数量
    private Integer remainNum;
    //忙闲评分
    @ApiModelProperty(value = "忙闲评分")
    private Integer score;
    @TableField(fill = FieldFill.INSERT)
    private Date createTime;
    @TableField(fill = FieldFill.UPDATE)
    private Date updateTime;


    /**
     * 获取主键值
     *
     * @return 主键值
     */
    @Override
    protected Serializable pkVal() {
        return this.id;
    }


    // 可用号源 / 号源
    // >=0.5    0- 闲 -绿色
    // 0.2-0.5  1-忙碌-黄色
    // <=0.2    2-非常忙碌-红色
    // 无号院    -1 灰色
    public void setScoreByNum() {
        if (NumberUtil.isNotNullOrZero(this.reserveOrderNum)) {
            double roate = this.remainNum * 1.0 / this.reserveOrderNum;
            if (roate >= 0.5) {
                this.setScore(0);
            } else if (roate > 0.2 && roate < 0.5) {
                this.setScore(1);
            } else {
                this.setScore(2);
            }
        } else {
            this.setScore(-1);
        }
    }
}
